@@ -14,11 +14,11 @@ unsigned int get_buffer_used(buffer_t *b);
 
 void my_emitter_set_output(yaml_emitter_t *e, buffer_t *b);
 
-unsigned char const * get_parser_error_problem(yaml_parser_t *p);
-unsigned char const * get_parser_error_context(yaml_parser_t *p);
+char const * get_parser_error_problem(yaml_parser_t *p);
+char const * get_parser_error_context(yaml_parser_t *p);
 unsigned int    get_parser_error_offset(yaml_parser_t *p);
 
-unsigned char const * get_emitter_error(yaml_emitter_t *e);
+char const * get_emitter_error(yaml_emitter_t *e);
 
 int simple_document_start(yaml_event_t *e);
 
